%global maj 17.12

Name:          rosegarden4
Version:       %{maj}
Release:       4%{?dist}
Summary:       MIDI, audio and notation editor
Group:         Applications/Multimedia
License:       GPLv2+
URL:           http://www.rosegardenmusic.com/
Source0:       http://downloads.sourceforge.net/project/rosegarden/rosegarden/%{maj}/rosegarden-%{version}.tar.bz2
# From         http://downloads.sourceforge.net/project/rosegarden/rosegarden/%%{maj}-LINUX/README
Source1:       rosegarden-%{maj}.README

Source2:       qmake-qt5.sh

# Fedora doesn't want fonts built into the final binary
Patch0:        rosegarden-separate-fonts.patch

BuildRequires: alsa-lib-devel
BuildRequires: desktop-file-utils
BuildRequires: dssi-devel
BuildRequires: fftw-devel
BuildRequires: fontpackages-devel
BuildRequires: jack-audio-connection-kit-devel
BuildRequires: cmake
BuildRequires: qt5-qtbase-devel
BuildRequires: qt5-linguist
BuildRequires: qt5-qtx11extras-devel
BuildRequires: ladspa-devel
BuildRequires: liblo-devel
BuildRequires: liblrdf-devel
BuildRequires: libsamplerate-devel
BuildRequires: libsndfile-devel
BuildRequires: lirc-devel
BuildRequires: libappstream-glib
BuildRequires: zlib-devel

Provides:      rosegarden = %{version}-%{release}

Requires:      %{name}-feta-fonts = %{version}-%{release}
Requires:      %{name}-parmesan-fonts = %{version}-%{release}

%description
Rosegarden is a professional audio and MIDI sequencer, score editor, and
general purpose music composition and editing environment.

Rosegarden is an easy to learn, attractive application, ideal for composers,
musicians, music students, and small studio or home recording environments.

%package feta-fonts
Summary:       Rosegarden feta fonts
Group:         User Interface/X
BuildArch:     noarch
Requires:      fontpackages-filesystem

%description feta-fonts
Rosegarden is a professional audio and MIDI sequencer, score editor, and
general purpose music composition and editing environment.

This package contains Lilypond's feta musical notation fonts adapted for use
of Rosegarden.

%package parmesan-fonts
Summary:       Rosegarden parmesan fonts
Group:         User Interface/X
BuildArch:     noarch
Requires:      fontpackages-filesystem

%description parmesan-fonts
Rosegarden is a professional audio and MIDI sequencer, score editor, and
general purpose music composition and editing environment.

This package contains Lilypond's parmesan musical notation fonts adapted for
use of Rosegarden.

%prep
%setup -q -n rosegarden-%{version}
%patch0 -p1 -b .fonts

# Release notes
cp -a %{SOURCE1} ./README.%{maj}

# Fix permissions:
chmod 644 src/gui/widgets/BaseTextFloat.*

%build
# force use of custom/local qmake, to inject proper build flags (above)
install -m755 -D %{SOURCE2} bin/qmake-qt5
PATH=`pwd`/bin:%{_qt5_bindir}:$PATH; export PATH

mkdir build
cd build
%cmake .. -DCMAKE_INSTALL_PREFIX=%{_prefix}
make %{?_smp_mflags}

%install
cd build
make install DESTDIR=%{buildroot}
cd ..
# Update the screenshot shown in the software center
#
# NOTE: It would be *awesome* if this file was pushed upstream.
#
# See http://people.freedesktop.org/~hughsient/appdata/#screenshots for more details.
#
appstream-util replace-screenshots $RPM_BUILD_ROOT%{_datadir}/metainfo/rosegarden.appdata.xml \
  https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/rosegarden/a.png \
  https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/rosegarden/b.png \
  https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/rosegarden/c.png
desktop-file-install \
%if %fedora < 19
  --vendor fedora \
%endif
  --dir %{buildroot}%{_datadir}/applications \
  --delete-original \
  --remove-category X-SuSE-Sequencer \
  --remove-category X-Red-Hat-Base \
  %{buildroot}%{_datadir}/applications/com.rosegardenmusic.rosegarden.desktop

# Install fonts in the %%_fontdir
mkdir -p %{buildroot}/%{_fontdir}
install -pm 644 data/fonts/*.pfa %{buildroot}/%{_fontdir}

%post
touch --no-create %{_datadir}/icons/locolor &>/dev/null || :

%postun
touch --no-create %{_datadir}/icons/locolor &>/dev/null || :

%files

%doc AUTHORS CONTRIBUTING README
%doc README.%{maj}
%{_bindir}/rosegarden
%{_datadir}/applications/*rosegarden.desktop
%{_datadir}/icons/hicolor/*/mimetypes/application-x-rosegarden-*.png
%{_datadir}/icons/hicolor/*/apps/rosegarden.png
%{_datadir}/mime/packages/rosegarden.xml
%{_datadir}/metainfo/rosegarden.appdata.xml

%_font_pkg -n feta *feta*.pfa
%doc data/fonts/README COPYING

%_font_pkg -n parmesan *parmesan*.pfa
%doc data/fonts/README COPYING

%changelog
* Wed Mar 07 2018 Adam Williamson <awilliam@redhat.com> - 17.12-4
- Rebuild to fix GCC 8 mis-compilation
  See https://da.gd/YJVwk ("GCC 8 ABI change on x86_64")

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 17.12-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jan 18 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 17.12-2
- Remove obsolete scriptlets

* Sun Dec 24 2017 Brendan Jones <brendan.jones.it@gmail.com> - 17.12-1
- Update to 17.12

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 16.02-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Apr 25 2016 Brendan Jones <brendan.jones.it@gmail.com> 16.02-2
- Ensure we are in the right directory
- Correct changelog

* Sun Apr 24 2016 Brendan Jones <brendan.jones.it@gmail.com> 16.02-1
- Update to 16.02

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 15.10.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Nov 23 2015 Brendan Jones <brendan.jones.it@gmail.com> - 15.10-1
- Update to 15.10

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 14.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon May 04 2015 Brendan Jones <brendan.jones.it@gmail.com> 14.12-1
- Update to 14.12

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 14.02-6
- Rebuilt for GCC 5 C++11 ABI change

* Mon Mar 30 2015 Richard Hughes <rhughes@redhat.com> - 14.02-5
- Use better AppData screenshots

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Tue Aug 12 2014 Rex Dieter <rdieter@fedoraproject.org> 14.02-3
- add mime scriptlet

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 14.02-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun May 04 2014 Brendan Jones <brendan.jones.it@gmail.com> -1
- Update to 14.02

* Tue Nov 05 2013 Brendan Jones <brendan.jones.it@gmail.com> 13.10-1
- Update to 13.10

* Mon Sep 30 2013 Brendan Jones <brendan.jones.it@gmail.com> 13.06-2
- Add appdata file
- Clean up changelog

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 13.04-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Apr 22 2013 Brendan Jones <brendan.jones.it@gmail.com> 13.04-1
- Update to 13.04

* Wed Feb 13 2013 Brendan Jones <brendan.jones.it@gmail.com> 12.12.25-4
- Reinstate vendor for < 19

* Mon Feb 11 2013 Brendan Jones <brendan.jones.it@gmail.com> 12.12.25-3
- Correct sources

* Mon Feb 11 2013 Brendan Jones <brendan.jones.it@gmail.com> 12.12.25-2
- Remove desktop vendor
- Remove plugin path patch

* Thu Jan 10 2013 Brendan Jones <brendan.jones.it@gmail.com> 12.12.25-1
- Update to 12.12.25

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 12.04-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu May 10 2012 Brendan Jones <brendan.jones.it@gmail.com> - 12.04-1
- New upstream 12.04
- rmove gcc patch accepted upstream

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 11.11.42-2
- Rebuilt for c++ ABI breakage

* Tue Jan 17 2012 Brendan Jones <brendan.jones.it@gmail.com> - 11.11.42-1
- Patch for GCC 4.7 FTB
- New upstream 11.11.42

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 11.11.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun Nov 27 2011 Brendan Jones <brendan.jones.it@gmail.com> - 11.11.11-1
- Update to 11.11 and README
- Update spec to current guidelines

* Sun May 15 2011 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 11.06-1
- Update to 11.06

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 11.02-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Feb 03 2011 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 11.02-1
- Update to 11.02

* Sat Nov 06 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 10.10-1
- Update to 10.10

* Tue Jul 20 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 10.04.2-2
- Rebuild against new liblo
- Fix the license file issue

* Sun May 09 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 10.04.2-1
- Update to 10.04.2
- Drop upstreamed qt-4.7 patch

* Thu Apr 22 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 10.04-1
- Update to 10.04
- BR qt-devel instead of kdelibs-devel
- Add release notes to %%doc
- Patch for build against qt-4.7

* Thu Feb 18 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 10.02.1-1
- Update to 10.02.1 (Qt4 version)

* Sat Feb 13 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 1.7.3-6
- Fix DSO linking RHBZ#564747

* Wed Nov 25 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 1.7.3-5
- Font subpackages are noarch
- Rebuild needed (something broke the ABI?)

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sat Mar 07 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 1.7.3-3
- The software makes use of kdialog. Thus we re-add Requires: kdebase.

* Sat Mar 07 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 1.7.3-2
- Add Requires: perl-XML-Twig. RHBZ#468919
- Fix the lilypondview script. RHBZ#464046
- Separate fonts to their own subpackages RHBZ#477450

* Fri Mar 06 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 1.7.3-1
- New upstream version.

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Apr 02 2008 Rex Dieter <rdieter@fedoraproject.org> -  1.6.1-2
- fix rawhide build (#434424)
- drop: Requires: kdebase3 (don't want a hard dep here)
- drop scriptlet deps (undesirable)
- fix 64bit platform %%if

* Wed Feb 13 2008 Callum Lerwick <seg@haxxed.com> - 1.6.1-1
- New upstream version.

* Wed Dec 12 2007 Callum Lerwick <seg@haxxed.com> - 1.6.0-1
- New upstream version.
- Patch cmakelists to use our optflags. (bz330631)

* Wed May 02 2007 Callum Lerwick <seg@haxxed.com> - 1.5.1-1
- New upstream version.

* Tue Feb 13 2007 Callum Lerwick <seg@haxxed.com> - 1.5.0-1
- New upstream version.

* Sat Nov 11 2006 Callum Lerwick <seg@haxxed.com> - 1.4.0-1
- New upstream version.

* Tue Sep 05 2006 Callum Lerwick <seg@haxxed.com> - 1.2.3-5
- Bump for FC6 mass rebuild.

* Sun Jul 23 2006 Callum Lerwick <seg@haxxed.com> - 1.2.3-4
- Add dependency on kdebase so help works.

* Sun Jul 16 2006 Callum Lerwick <seg@haxxed.com> - 1.2.3-3
- Look for DSSI plugins in the correct place on x86_64.
- Add gettext BR.

* Sat Jun 17 2006 Callum Lerwick <seg@haxxed.com> - 1.2.3-2
- Removed which from Buildrequires, mock needing it is confirmed to be a bug.
- Use find_lang macro.
- Look for ladspa plugins in the correct place on x86_64.
- Build against liblo, jack, dssi, lirc.
- Salvage the upstream desktop file, rather than using our own.

* Sat Apr 15 2006 Callum Lerwick <seg@haxxed.com> - 1.2.3-1
- Initial packaging for Extras.
